schemetools.SchemeColor
=======================

.. inheritance-diagram:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor
   :private-bases:

.. autoclass:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.format

   .. note:: Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`

Special Methods
---------------

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__delattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__eq__

   .. note:: Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__ge__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__gt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__hash__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__le__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__lt__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__ne__

   .. note:: Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__repr__

   .. note:: Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__setattr__

   .. note:: Inherited from `__builtin__.object`

.. automethod:: abjad.tools.schemetools.SchemeColor.SchemeColor.SchemeColor.__str__

   .. note:: Inherited from :py:class:`schemetools.Scheme <abjad.tools.schemetools.Scheme.Scheme.Scheme>`
